@@ -3,7 +3,7 @@ import json
 from argparse import Namespace
 from typing import Iterable
 
-from ldb.cli_utils import add_data_object_arguments
+from ldb.cli_utils import add_data_obj_params
 from ldb.core import get_ldb_instance
 from ldb.evaluate import evaluate
 
@@ -12,8 +12,7 @@ def evaluate_command(options: Namespace) -> None:
     for data_object_hash, *results in evaluate(
         get_ldb_instance(),
         options.paths,
-        options.annotation_query,
-        options.file_query,
+        options.query_args,
     ):
         if not options.json_only:
             print(f"0x{data_object_hash}")
@@ -39,5 +38,5 @@ def add_parser(
         default=False,
         help="Show JSON output only instead of showing object hashes",
     )
-    add_data_object_arguments(parser)
+    add_data_obj_params(parser, dest="query_args")
     parser.set_defaults(func=evaluate_command)
