@@ -3,7 +3,9 @@ from argparse import Namespace
 from pathlib import Path
 from typing import Iterable
 
+from ldb.cli_utils import add_data_format_arguments
 from ldb.core import get_ldb_instance
+from ldb.data_formats import INSTANTIATE_FORMATS, Format
 from ldb.instantiate import instantiate
 from ldb.utils import format_dataset_identifier
 from ldb.workspace import load_workspace_dataset
@@ -15,15 +17,16 @@ def instantiate_command(options: Namespace) -> None:
     workspace_ds = load_workspace_dataset(workspace_path)
     ds_ident = format_dataset_identifier(workspace_ds.dataset_name)
     print(f"Instantiating working dataset {ds_ident}...\n")
-    num_data_objects, num_annotations = instantiate(
+    result = instantiate(
         ldb_dir,
         workspace_path,
+        fmt=options.format,
         force=options.force,
     )
     print(
         "Copied dataset to workspace.\n"
-        f"  Data objects: {num_data_objects:9d}\n"
-        f"  Annotations:  {num_annotations:9d}",
+        f"  Data objects: {result.num_data_objects:9d}\n"
+        f"  Annotations:  {result.num_annotations:9d}",
     )
 
 
@@ -36,6 +39,11 @@ def add_parser(
         parents=parents,
         help="Instantiate the current workspace dataset",
     )
+    add_data_format_arguments(
+        parser,
+        default=Format.BARE,
+        formats=INSTANTIATE_FORMATS,
+    )
     parser.add_argument(
         "-f",
         "--force",
