@@ -2,7 +2,7 @@ import argparse
 from argparse import Namespace
 from typing import Iterable
 
-from ldb.cli_utils import add_data_object_arguments
+from ldb.cli_utils import add_data_obj_params
 from ldb.core import get_ldb_instance
 from ldb.ls import ls, print_dataset_listings
 
@@ -12,8 +12,7 @@ def ls_command(options: Namespace) -> None:
     ds_listings = ls(
         ldb_dir,
         options.paths,
-        options.annotation_query,
-        options.file_query,
+        options.query_args,
     )
     if options.summary:
         print(len(ds_listings))
@@ -41,5 +40,5 @@ def add_parser(
         default=False,
         help="Show the number of objects instead of listing them out",
     )
-    add_data_object_arguments(parser)
+    add_data_obj_params(parser, dest="query_args")
     parser.set_defaults(func=ls_command)
